[gnus git] branch master updated: m0-5-318-g049ddf2 =1= gnus-util.el (gnus-emacs-completing-read): Fix a filter for XEmacs

Katsumi Yamaoka <[email protected]>
Newsgroups gmane.emacs.gnus.cvs
Message-ID <[email protected]>
       via  049ddf277320f322666ebf272e2a2969623a873d (commit)
      from  ffe73a4b8ec7341ac4b689b4d4a1cc60cc73eec3 (commit)


- Log -----------------------------------------------------------------
commit 049ddf277320f322666ebf272e2a2969623a873d
Author: Katsumi Yamaoka <[email protected]>
Date:   Wed May 1 00:28:57 2013 +0000

    gnus-util.el (gnus-emacs-completing-read): Fix a filter for XEmacs

diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index 7c38ac5..a6bf08f 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -1,3 +1,7 @@
+2013-05-01  Katsumi Yamaoka  <[email protected]>
+
+	* gnus-util.el (gnus-emacs-completing-read): Fix a filter for XEmacs.
+
 2013-04-27  Glenn Morris  <[email protected]>
 
 	* gnus.el (gnus-list-debbugs):
diff --git a/lisp/gnus-util.el b/lisp/gnus-util.el
index 331f955..a121c27 100644
--- a/lisp/gnus-util.el
+++ b/lisp/gnus-util.el
@@ -1549,9 +1549,12 @@ SPEC is a predicate specifier that contains stuff like `or', `and',
   "Call standard `completing-read-function'."
   (let ((completion-styles gnus-completion-styles))
     (completing-read prompt
-                     ;; Old XEmacs (at least 21.4) expect an alist for
-                     ;; collection.
-                     (mapcar 'list collection)
+                     ;; Old XEmacs (at least 21.4) expect an alist,
+		     ;; in which the car of each element is a string,
+		     ;; for collection.
+                     (mapcar (lambda (elem)
+			       (list (format "%s" (or (car-safe elem) elem))))
+			     collection)
                      nil require-match initial-input history def)))
 
 (autoload 'ido-completing-read "ido")

-----------------------------------------------------------------------
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we listed those
revisions in full, above.

Summary of changes:
 lisp/ChangeLog    |    4 ++++
 lisp/gnus-util.el |    9 ++++++---
 2 files changed, 10 insertions(+), 3 deletions(-)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Gnus Project".

The branch, master has been updated


hooks/post-receive
-- 
Gnus Project
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.